@@ -1,6 +1,6 @@
 /***************************************************************************
                           kpopup.cpp  -  description
-                          --------------------------
+                             -------------------
     copyright            : (C) 2000 by Torsten Henschel
     email                : henschel@fh-brandenburg.de
  ***************************************************************************/
@@ -15,24 +15,34 @@
  ***************************************************************************/
 
 #include <malloc.h>
+#include <stdio.h>
 
-#include <kapp.h>
+#include <kiconloader.h>
 
+#include <qtimer.h>
+
+#include "kpopup.h"
 #include "make_popup.h"
 #include "misc.h"
-#include "kpopup.h"
+#include "resource.h"
 
+#define i18n(x) tr(x)
 
-Kpopup::Kpopup(int argc, char **argv, QWidget *parent, const char *name) : KTMainWindow (name)
+Kpopup::Kpopup(int argc, char **argv)
 {
- setMinimumSize(290, 260);
- setMaximumSize(290, 260);
+ setMinimumSize(282, 260);
+ setMaximumSize(282, 260);
 
  Init();
  InitToolbar();
  InitStatusbar();
 
- SetStatusText(i18n("Welcome to Kpopup " + QString(VERSION)));
+ toolbar -> show();
+ statusbar -> show();
+ addToolBar(toolbar);
+ setStatusBar(statusbar);
+
+ SetStatusText(i18n("Welcome to KPopup ") + QString(VERSION));
  timer -> start(3000, TRUE);
 
  if(argc == 3)
@@ -66,10 +76,12 @@ Kpopup::Kpopup(int argc, char **argv, QWidget *parent, const char *name) : KTMai
  L_Label_DateTime -> setGeometry(22, 63, 98, 20);
  L_Label_DateTime -> setAlignment(AlignTop | AlignLeft);
 
+ TV_Text = new QTextView(this);
+ TV_Text -> setGeometry(12, 85, 258, 150);
+
  if(strlen(Filename) != 0)
    {
-    L_PopupText = new QLabel(File_read(Filename, 41), this);
-
+    TV_Text -> setText(File_read(Filename));
     Time = new QTime();
     *Time = Time -> currentTime();
     Date = new QDate();
@@ -78,18 +90,12 @@ Kpopup::Kpopup(int argc, char **argv, QWidget *parent, const char *name) : KTMai
    }
   else
    {
-    L_PopupText = new QLabel("", this);
-
     L_DateTime = new QLabel("", this);
    }
 
  L_DateTime -> setGeometry(100, 60, 170, 20);
  L_DateTime -> setFrameStyle(QFrame::Panel | QFrame::Sunken);
  L_DateTime -> setAlignment(AlignTop | AlignLeft);
-
- L_PopupText -> setGeometry(20, 85, 250, 150);
- L_PopupText -> setFrameStyle(QFrame::Panel | QFrame::Sunken);
- L_PopupText -> setAlignment(AlignTop | AlignLeft);
 }
 
 
@@ -101,80 +107,30 @@ Kpopup::~Kpopup()
 void Kpopup::Init()
 {
  timer = new QTimer(this);
- connect(timer, SIGNAL(timeout()), this, SLOT(timerDone()));
+ connect(timer, SIGNAL(timeout()), this, SLOT(TimerDone()));
 }
 
+
 void Kpopup::InitToolbar()
 {
  toolbar = new KToolBar(this);
- loader = kapp -> getIconLoader();
 
- toolbar -> insertButton(loader -> loadMiniIcon("exit.xpm"), ID_EXIT, TRUE, i18n("Quit"));
+ toolbar -> insertButton(BarIcon("exit"), ID_EXIT, TRUE, i18n("Quit"));
  toolbar -> insertSeparator();
- toolbar -> insertButton(loader -> loadMiniIcon("filenew.xpm"), ID_NEW_POPUP, TRUE, i18n("New Popup"));
- toolbar -> insertButton(loader -> loadMiniIcon("reload.xpm"), ID_ANSWER_POPUP, TRUE, i18n("Answer Popup"));
+ toolbar -> insertButton(BarIcon("filenew"), ID_NEW_POPUP, TRUE, i18n("New Popup"));
+ toolbar -> insertButton(BarIcon("reload"), ID_ANSWER_POPUP, TRUE, i18n("Answer Popup"));
  toolbar -> insertSeparator();
  toolbar -> insertSeparator();
- toolbar -> insertButton(loader -> loadMiniIcon("help.xpm"), ID_HELP, TRUE, i18n("Help"));
+ toolbar -> insertButton(BarIcon("help"), ID_HELP, TRUE, i18n("Help"));
 
  connect(toolbar, SIGNAL(clicked(int)), SLOT(commandCallback(int)));
-
- toolbar -> show();
- addToolBar(toolbar);
- toolbar -> setBarPos(KToolBar::Top);
 }
 
 
 void Kpopup::InitStatusbar()
 {
  statusbar = new KStatusBar(this);
-
- statusbar -> insertItem("", ID_STATUS_TEXT);
- statusbar -> show();
- setStatusBar(statusbar);
-}
-
-
-void Kpopup::AnswerPopup()
-{
- if(strlen(Sender) != 0)
-   {
-    make_Popup *AnswerPopupView;
-
-    AnswerPopupView = new make_Popup(this, "Blabla");
-    AnswerPopupView -> resize(280, 220);
-    AnswerPopupView -> setCaption(i18n("Answer Popup"));
-    AnswerPopupView -> CB_Receiver -> insertItem(Sender, -1);
-    AnswerPopupView -> ReadBrowseList();
-    AnswerPopupView -> CB_Receiver -> setCurrentItem(0);
-    AnswerPopupView -> exec();
-   }
-  else
-   {
-    make_Popup *NewPopupView;
-
-    NewPopupView = new make_Popup(this, "Blabla");
-    NewPopupView -> resize(280, 220);
-    NewPopupView -> setCaption(i18n("New Popup"));
-    NewPopupView -> CB_Receiver -> insertItem("NO HOST", -1);
-    NewPopupView -> ReadBrowseList();
-    NewPopupView -> CB_Receiver -> setCurrentItem(0);
-    NewPopupView -> exec();
-   }
-}
-
-
-void Kpopup::NewPopup()
-{
- make_Popup *NewPopupView;
-
- NewPopupView = new make_Popup(this, "Blabla");
- NewPopupView -> resize(280, 220);
- NewPopupView -> setCaption(i18n("New Popup"));
- NewPopupView -> CB_Receiver -> insertItem("NO HOST", -1);
- NewPopupView -> ReadBrowseList();
- NewPopupView -> CB_Receiver -> setCurrentItem(0);
- NewPopupView -> exec();
+ statusBar() -> insertItem("", ID_STATUS_TEXT, 1, true);
 }
 
 
@@ -193,11 +149,12 @@ void Kpopup::commandCallback(int id_)
                         break;
    case ID_HELP:
 								kapp -> invokeHTMLHelp("", "");
-                break;		
+                break;
   }
 }
 
-void Kpopup::timerDone()
+
+void Kpopup::TimerDone()
 {
  statusbar -> changeItem("", ID_STATUS_TEXT);
 }
@@ -206,4 +163,47 @@ void Kpopup::timerDone()
 void Kpopup::SetStatusText(const char *text)
 {
  statusbar -> changeItem(text, ID_STATUS_TEXT);
-}
\ No newline at end of file
+}
+
+
+void Kpopup::NewPopup()
+{
+ make_Popup *NewPopupView;
+
+ NewPopupView = new make_Popup(this, "New Popup");
+ NewPopupView -> resize(280, 220);
+ NewPopupView -> setCaption(i18n("New Popup"));
+ NewPopupView -> CB_Receiver -> insertItem("NO HOST", -1);
+ NewPopupView -> ReadBrowseList();
+ NewPopupView -> CB_Receiver -> setCurrentItem(0);
+ NewPopupView -> exec();
+}
+
+
+void Kpopup::AnswerPopup()
+{
+ if(strlen(Sender) != 0)
+   {
+    make_Popup *AnswerPopupView;
+
+    AnswerPopupView = new make_Popup(this, "Answer Popup");
+    AnswerPopupView -> resize(280, 220);
+    AnswerPopupView -> setCaption(i18n("Answer Popup"));
+    AnswerPopupView -> CB_Receiver -> insertItem(Sender, -1);
+    AnswerPopupView -> ReadBrowseList();
+    AnswerPopupView -> CB_Receiver -> setCurrentItem(0);
+    AnswerPopupView -> exec();
+   }
+  else
+   {
+    make_Popup *NewPopupView;
+
+    NewPopupView = new make_Popup(this, "Answer Popup");
+    NewPopupView -> resize(280, 220);
+    NewPopupView -> setCaption(i18n("New Popup"));
+    NewPopupView -> CB_Receiver -> insertItem("NO HOST", -1);
+    NewPopupView -> ReadBrowseList();
+    NewPopupView -> CB_Receiver -> setCurrentItem(0);
+    NewPopupView -> exec();
+   }
+}
