@@ -1,6 +1,7 @@
+
 /***************************************************************************
                           main.cpp  -  description
-                          ------------------------
+                             -------------------
     copyright            : (C) 2000 by Torsten Henschel
     email                : henschel@fh-brandenburg.de
  ***************************************************************************/
@@ -14,29 +15,43 @@
  *                                                                         *
  ***************************************************************************/
 
-#include <kapp.h>
+#include <kcmdlineargs.h>
+#include <kaboutdata.h>
+#include <klocale.h>
 
-#include <kpopup.h>
+#include "kpopup.h"
 
-int main(int argc, char **argv)
+static const char *description = "KPopup";
+// INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
+	
+	
+static KCmdLineOptions options[] =
 {
- KApplication a(argc, argv, "kpopup");
- if(argc != 1)
+  { 0, 0, 0 }
+  // INSERT YOUR COMMANDLINE OPTIONS HERE
+};
+
+int main(int argc, char *argv[])
+{
+
+  KAboutData aboutData("kpopup", "KPopup", VERSION, description, KAboutData::License_GPL,
+                       "(c) 2000, Torsten Henschel");
+  aboutData.addAuthor("Torsten Henschel", 0, "henschel@fh-brandenburg.de");
+  KCmdLineArgs::init(argc, argv, &aboutData);
+  KCmdLineArgs::addCmdLineOptions(options); // Add our own options.
+
+  KApplication a(argc, argv, "kpopup");
+
+  if(argc != 1)
    {
     a.beep();
    }
-// if (a.isRestored())
-//		RESTORE(Komba)
-//	else {
- Kpopup *w = new Kpopup(argc, argv);
- w -> setGeometry(100, 100, 400, 400);
- w -> setCaption("Kpopup");
- if(argc != 1)
-   {
-    a.beep();
-   }
- a.setMainWidget(w);
- w -> show();
-//	}
- return a.exec();
+
+  Kpopup *w = new Kpopup(argc, argv);
+  w -> setGeometry(100, 100, 400, 400);
+  w -> setCaption("KPopup");
+  a.setMainWidget(w);
+  w -> show();
+
+  return a.exec();
 }
