@@ -19,15 +19,18 @@
 #include <stdio.h>
 #include <unistd.h>
 
-#include <kmsgbox.h>
+#include <kmessagebox.h>
 
-#include "make_popup.h"
-#include "misc.h"
+#include <qfile.h>
+
+#include <make_popup.h>
+#include <misc.h>
+
+#define i18n(x) tr(x)
 
 make_Popup::make_Popup(QWidget *parent, const char *name) : KDialog(parent, name, TRUE)
 {
  hostname = (char *) malloc (30 * (sizeof(char)));
-
  ReadHostName();
 
  B_Ok = new QPushButton(i18n("Ok"), this);
@@ -41,7 +44,7 @@ make_Popup::make_Popup(QWidget *parent, const char *name) : KDialog(parent, name
  L_Receiver = new QLabel(i18n("To:"), this);
  L_Receiver -> setGeometry(20, 9, 30, 20);
 
- CB_Receiver = new QComboBox(TRUE, this, "read-write combo");
+ CB_Receiver = new QComboBox(TRUE, this);
  CB_Receiver -> setGeometry(55, 8, 205, 22);
 
  L_Text = new QLabel(i18n("Text:"), this);
@@ -54,7 +57,6 @@ make_Popup::make_Popup(QWidget *parent, const char *name) : KDialog(parent, name
  setMaximumSize(280, 195);
 }
 
-
 make_Popup::~make_Popup()
 {
  free(hostname);
@@ -68,24 +70,23 @@ void make_Popup::SendPopup()
  int linecount = 0;
 
  commandline = (char *) malloc (182 * (sizeof(char)));
-
- sprintf(commandline, "%s/smbclient -M %s -N -U %s > /dev/null", SMBPATH, CB_Receiver -> currentText(), hostname);
+ sprintf(commandline, "%s/smbclient -M %s -N -U %s > /dev/null", SMBPATH, (const char *)CB_Receiver->currentText(), hostname);
 
  if((sendprocess = popen(commandline, "w")) != 0)
    {
     while(linecount < MLE_Text -> numLines())
      {
-      fprintf(sendprocess, "%s\n", MLE_Text -> textLine(linecount));
+      fprintf(sendprocess, "%s\n", (const char *)MLE_Text -> textLine(linecount));
       linecount++;
      }
    if(pclose(sendprocess) == 0)
      {
-      KMsgBox::message(this, i18n("Success"), i18n("Popup sent!"), KMsgBox::INFORMATION, "Ok");
+      KMessageBox::information(this, i18n("Popup sent!"), i18n("Success"));
       reject();
      }
     else
      {
-      KMsgBox::message(this, i18n("Error"), i18n("Popup not sent!"), KMsgBox::INFORMATION, "Ok");
+      KMessageBox::sorry(this, i18n("Popup not sent!"), i18n("Error"));
      }
    }
 
@@ -93,6 +94,13 @@ void make_Popup::SendPopup()
 }
 
 
+void make_Popup::ReadHostName()
+{
+ gethostname(hostname, 30);
+ for(int i = 0; i <= 29; i++) hostname[i] = toupper(hostname[i]);
+}
+
+
 void make_Popup::ReadBrowseList()
 {
  QFile *hostfile;
@@ -133,10 +141,3 @@ void make_Popup::ReadBrowseList()
     hostfile -> close();
    }
 }
-
-
-void make_Popup::ReadHostName()
-{
- gethostname(hostname, 30);
- for(int i = 0; i <= 29; i++) hostname[i] = toupper(hostname[i]);
-}
