@@ -20,6 +20,6 @@
 //Path of smbclient
 #define SMBPATH "/usr/bin"
 
-char *File_read(const char *Filename, int ZLaenge);
+char *File_read(const char *Filename);
 
-#endif
\ No newline at end of file
+#endif
